==> jc-1.4.0.tar.gz: java/rmi/activation/ActivationID.h <==
// public class java.rmi.activation.ActivationID

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4e01cf9f8faf6084 java_rmi_activation_ActivationID

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_rmi_activation_ActivationID_H_
#define _JC_java_rmi_activation_ActivationID_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_rmi_Remote$object;
struct _jc_java_rmi_activation_Activator$object;

// Typedefs
typedef struct _jc_java_rmi_activation_ActivationID$sub_refs	_jc_java_rmi_activation_ActivationID$sub_refs;
typedef struct _jc_java_rmi_activation_ActivationID$sub_nonrefs	_jc_java_rmi_activation_ActivationID$sub_nonrefs;
typedef struct _jc_java_rmi_activation_ActivationID$refs	_jc_java_rmi_activation_ActivationID$refs;
typedef struct _jc_java_rmi_activation_ActivationID$nonrefs	_jc_java_rmi_activation_ActivationID$nonrefs;
typedef struct _jc_java_rmi_activation_ActivationID$object	_jc_java_rmi_activation_ActivationID$object;

typedef struct _jc_java_rmi_activation_ActivationID$fields_struct	_jc_java_rmi_activation_ActivationID$fields_struct;
typedef const struct _jc_java_rmi_activation_ActivationID$vmethods	_jc_java_rmi_activation_ActivationID$vmethods;
typedef const struct _jc_java_rmi_activation_ActivationID$vtable	_jc_java_rmi_activation_ActivationID$vtable;
typedef const struct _jc_java_rmi_activation_ActivationID$vtype	_jc_java_rmi_activation_ActivationID$vtype;

// Class fields structure
struct _jc_java_rmi_activation_ActivationID$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_rmi_activation_ActivationID$fields_struct _jc_java_rmi_activation_ActivationID$class_fields;

// Constructors
extern void _jc_java_rmi_activation_ActivationID$method$_init$f9c50d0640ea0bd4(_jc_env *, struct _jc_java_rmi_activation_ActivationID$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_object *_jc_java_rmi_activation_ActivationID$method$activate$b6750631be099f58(_jc_env *, struct _jc_java_rmi_activation_ActivationID$object *, jboolean);
extern jboolean _jc_java_rmi_activation_ActivationID$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_rmi_activation_ActivationID$object *, struct _jc_java_lang_Object$object *);
extern jint _jc_java_rmi_activation_ActivationID$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_rmi_activation_ActivationID$object *);

// Virtual method descriptors
extern _jc_method _jc_java_rmi_activation_ActivationID$method_info$activate$b6750631be099f58;
extern _jc_method _jc_java_rmi_activation_ActivationID$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_rmi_activation_ActivationID$method_info$hashCode$53152098849316df;

// Virtual methods structure
struct _jc_java_rmi_activation_ActivationID$vmethods {
	struct _jc_object	*(*activate$b6750631be099f58)(_jc_env *, struct _jc_java_rmi_activation_ActivationID$object *, jboolean);
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_rmi_activation_ActivationID$object *, struct _jc_java_lang_Object$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_rmi_activation_ActivationID$object *);
};

// Vtable
struct _jc_java_rmi_activation_ActivationID$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_rmi_activation_ActivationID$vmethods	java_rmi_activation_ActivationID;
};

// Vtype
struct _jc_java_rmi_activation_ActivationID$vtype {
	_jc_type			type;
	_jc_java_rmi_activation_ActivationID$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_rmi_activation_ActivationID$sub_refs {
	struct _jc_object	*activator;
};

// Reference instance fields (object)
struct _jc_java_rmi_activation_ActivationID$refs {
    _jc_java_rmi_activation_ActivationID$sub_refs	java_rmi_activation_ActivationID;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_rmi_activation_ActivationID$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_rmi_activation_ActivationID$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_rmi_activation_ActivationID$sub_nonrefs	java_rmi_activation_ActivationID;
};

// Object instance structure
struct _jc_java_rmi_activation_ActivationID$object {
	_jc_java_rmi_activation_ActivationID$refs	refs[0];
	_jc_word		lockword;
	_jc_java_rmi_activation_ActivationID$vtype	*vtype;
	_jc_java_rmi_activation_ActivationID$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_rmi_activation_ActivationID$vtype _jc_java_rmi_activation_ActivationID$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_rmi_activation_ActivationID, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_rmi_activation_ActivationID$class_object;

#endif	/* _JC_java_rmi_activation_ActivationID_H_ */

==> jc-1.4.6.tar.gz: java/rmi/activation/ActivationID.h <==
// public class java.rmi.activation.ActivationID

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4e01cf9f8faf6084 java_rmi_activation_ActivationID

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_rmi_activation_ActivationID_H_
#define _JC_java_rmi_activation_ActivationID_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_rmi_Remote$object;
struct _jc_java_rmi_activation_Activator$object;

// Typedefs
typedef struct _jc_java_rmi_activation_ActivationID$sub_refs	_jc_java_rmi_activation_ActivationID$sub_refs;
typedef struct _jc_java_rmi_activation_ActivationID$sub_nonrefs	_jc_java_rmi_activation_ActivationID$sub_nonrefs;
typedef struct _jc_java_rmi_activation_ActivationID$refs	_jc_java_rmi_activation_ActivationID$refs;
typedef struct _jc_java_rmi_activation_ActivationID$nonrefs	_jc_java_rmi_activation_ActivationID$nonrefs;
typedef struct _jc_java_rmi_activation_ActivationID$object	_jc_java_rmi_activation_ActivationID$object;

typedef struct _jc_java_rmi_activation_ActivationID$fields_struct	_jc_java_rmi_activation_ActivationID$fields_struct;
typedef const struct _jc_java_rmi_activation_ActivationID$vmethods	_jc_java_rmi_activation_ActivationID$vmethods;
typedef const struct _jc_java_rmi_activation_ActivationID$vtable	_jc_java_rmi_activation_ActivationID$vtable;
typedef const struct _jc_java_rmi_activation_ActivationID$vtype	_jc_java_rmi_activation_ActivationID$vtype;

// Class fields structure
struct _jc_java_rmi_activation_ActivationID$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_rmi_activation_ActivationID$fields_struct _jc_java_rmi_activation_ActivationID$class_fields;

// Constructors
extern void _jc_java_rmi_activation_ActivationID$method$_init$f9c50d0640ea0bd4(_jc_env *, struct _jc_java_rmi_activation_ActivationID$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_java_rmi_activation_ActivationID$method$activate$b6750631be099f58(_jc_env *, struct _jc_java_rmi_activation_ActivationID$object *, jboolean) _JC_JCNI_ATTR;
extern jboolean _jc_java_rmi_activation_ActivationID$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_rmi_activation_ActivationID$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jint _jc_java_rmi_activation_ActivationID$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_rmi_activation_ActivationID$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_rmi_activation_ActivationID$method_info$activate$b6750631be099f58;
extern _jc_method _jc_java_rmi_activation_ActivationID$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_rmi_activation_ActivationID$method_info$hashCode$53152098849316df;

// Virtual methods structure
struct _jc_java_rmi_activation_ActivationID$vmethods {
	struct _jc_object	*(*activate$b6750631be099f58)(_jc_env *, struct _jc_java_rmi_activation_ActivationID$object *, jboolean) _JC_JCNI_ATTR;
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_rmi_activation_ActivationID$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_rmi_activation_ActivationID$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_rmi_activation_ActivationID$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_rmi_activation_ActivationID$vmethods	java_rmi_activation_ActivationID;
};

// Vtype
struct _jc_java_rmi_activation_ActivationID$vtype {
	_jc_type			type;
	_jc_java_rmi_activation_ActivationID$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_rmi_activation_ActivationID$sub_refs {
	struct _jc_object	*activator;
};

// Reference instance fields (object)
struct _jc_java_rmi_activation_ActivationID$refs {
    _jc_java_rmi_activation_ActivationID$sub_refs	java_rmi_activation_ActivationID;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_rmi_activation_ActivationID$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_rmi_activation_ActivationID$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_rmi_activation_ActivationID$sub_nonrefs	java_rmi_activation_ActivationID;
};

// Object instance structure
struct _jc_java_rmi_activation_ActivationID$object {
	_jc_java_rmi_activation_ActivationID$refs	refs[0];
	_jc_word		lockword;
	_jc_java_rmi_activation_ActivationID$vtype	*vtype;
	_jc_java_rmi_activation_ActivationID$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_rmi_activation_ActivationID$vtype _jc_java_rmi_activation_ActivationID$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_rmi_activation_ActivationID, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_rmi_activation_ActivationID$class_object;

#endif	/* _JC_java_rmi_activation_ActivationID_H_ */
